==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/fdmainwindowplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MainWin</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="43"/>
        <source>Can not configure MedinTux</source>
        <translation>Impossible de configurer MedinTux</translation>
    </message>
</context>
<context>
    <name>MainWin::Internal::MainWinPrivate</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="122"/>
        <source>Reading exchange file...</source>
        <translation>Ouverture du fichier d&apos;échange...</translation>
    </message>
</context>
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="56"/>
        <source>DOB</source>
        <translation>DDN</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient Firstname</source>
        <translation>Nom du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="30"/>
        <source>Surname</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="42"/>
        <source>Patient information</source>
        <translation>Informations concernant le patient</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="69"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation>dd/MM/yyyy</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="76"/>
        <source>Weight</source>
        <translation>Poids</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="97"/>
        <source>Kg</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="102"/>
        <source>lbs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="110"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="131"/>
        <source>cm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="136"/>
        <source>m</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="141"/>
        <source>inches</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="149"/>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="162"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="167"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="172"/>
        <source>H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="184"/>
        <source>Creatinine clearance</source>
        <translation>Clearance de la créatinine</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="205"/>
        <source>mL/min</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="210"/>
        <source>mL/sec</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="218"/>
        <source>Creatinine</source>
        <translation>Créatinine</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="239"/>
        <source>mg/L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="244"/>
        <source>mg/dL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="249"/>
        <source>mmol/L</source>
        <translation></translation>
    </message>
    <message utf8="true">
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="254"/>
        <source>µmol/L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="266"/>
        <source>List of medications allergies</source>
        <translation>Liste des allergies médicamenteuses</translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="175"/>
        <source>Creating Main Window</source>
        <translation>Création de la fenêtre principale</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="234"/>
        <source>Transmitting posologies...</source>
        <translation>Transmition des posologies...</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="260"/>
        <source>Initializing drugs database</source>
        <translation>Initialisation de la base de données thérapeutique</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="266"/>
        <source>Entering selection mode</source>
        <translation>Entrée dans le mode de sélection seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="494"/>
        <source>Save actual prescription ?</source>
        <translation>Sauvegarder la prescription actuelle ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="495"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
        <translation>La prescription actuelle n&apos;est pas vide. Voulez-vous la sauvegarder avant d&apos;en créer une nouvelle ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="601"/>
        <source>Opening a prescription : merge or replace ?</source>
        <translation>Ouverture d&apos;une prescription : fusionner ou remplacer ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="602"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
        <translation>Il existe déjà une prescription dans l&apos;éditeur, voulez-vous la remplacer ou ajouter la nouvelle prescription ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="603"/>
        <source>Replace prescription</source>
        <translation>Remplacer la prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="603"/>
        <source>Add to prescription</source>
        <translation>Ajouter à la prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="604"/>
        <source>Open a prescription</source>
        <translation>Ouvrerture d&apos;une prescription</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="155"/>
        <source>Preparing dosage transmission</source>
        <translation>Préparation de la transmission des posologies</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="66"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Configuration automatique pour l&apos;utilisation avec MedinTux</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="67"/>
        <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
        <translation>Cet assistant va créer une nouvelle entrée dans le menu utilsateur de DrTux.
Vous pourrez créer de nouvelles prescriptions depuis ce menu.
Attention, assurez-vous de reconfigurer MedinTux grâce à cet assistant à chaque fois que MedinTux ou FreeDiams changera de répertoire.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="72"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Cet assistant va essayer de trouver votre configuration de MedinTux. S&apos;il ne trouve pas, vous devrez l&apos;en informer. Ensuite, cet assistant configurera un nouveau menu utilisateur et ajoutera une liste dans vos listes par défauts des prescriptions.
Merci de prendre connaissance de la documentation.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="87"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Veuillez sélectionner le répertoire contenant le binaire de Manager</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="98"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le répertoire des ressources n&apos;existe pas. Chemin vers DrTux : %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="102"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le menu utilisateur n&apos;existe pas et ne peut pas être créer. Chemin vers DrTux : %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="113"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Impossible d&apos;effacer l&apos;ancienne entrée de DrugsInteractions du menu %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="119"/>
        <source>Unable to configure MedinTux : DrugsInteractions menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le menu de FreeDiams n&apos;existe pas et ne peut pas être créé. Chemin vers Drux : %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="195"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux est maintenant configuré pour %1.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="196"/>
        <source>You can run %1 using DrTux User&apos;s Menu.</source>
        <translation>Vous pouvez utiliser %1 grâce au menu utilisateur de DrTux.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="197"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Si vous rencontrez des difficultés avec l&apos;intégration à DrTux, veuillez vous référer à la documentation des deux applications.
%1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="199"/>
        <source>DrTux is not correctly configured.</source>
        <translation>DrTux n&apos;est pas correctement configuré.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="200"/>
        <source>This assitant encountered errors during its process.</source>
        <translation>Cet assistant a rencontré des erreurs pendant la configuration.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="201"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Voici les messages des processus 
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="25"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Prescrire avec FreeDiams</translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/fdmainwindowplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="115"/>
        <source>DOB</source>
        <translation>DDN</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="107"/>
        <source>Patient information</source>
        <translation>Informations concernant le patient</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="128"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation>dd/MM/yyyy</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="135"/>
        <source>Weight</source>
        <translation>Poids</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="156"/>
        <source>Kg</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="161"/>
        <source>lbs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="190"/>
        <source>cm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="195"/>
        <source>m</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="200"/>
        <source>inches</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="208"/>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="169"/>
        <source>Height</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="27"/>
        <source>Family or occidental last names</source>
        <translation>Nom(s) de famille</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="34"/>
        <source>Firstname</source>
        <translation>Prénom(s)</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="41"/>
        <source>Given names</source>
        <translation>Prénom(s)</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="222"/>
        <source>Creatinine clearance</source>
        <translation>Clearance de la créatinine</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="243"/>
        <source>mL/min</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="248"/>
        <source>mL/sec</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="256"/>
        <source>Creatinine</source>
        <translation>Créatinine</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="277"/>
        <source>mg/L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="282"/>
        <source>mg/dL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="287"/>
        <source>mmol/L</source>
        <translation></translation>
    </message>
    <message utf8="true">
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="292"/>
        <source>µmol/L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="304"/>
        <source>Drugs precautions</source>
        <translation>Précautions</translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="234"/>
        <source>Creating Main Window</source>
        <translation>Création de la fenêtre principale</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="331"/>
        <source>Transmitting posologies...</source>
        <translation>Transmition des posologies...</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="356"/>
        <source>Connected to</source>
        <translation>Connecté à</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="371"/>
        <source>Initializing drugs database</source>
        <translation>Initialisation de la base de données thérapeutique</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="377"/>
        <source>Entering selection mode</source>
        <translation>Entrée dans le mode de sélection seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="386"/>
        <source>Reading exchange file...</source>
        <translation>Ouverture du fichier d&apos;échange...</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="718"/>
        <source>Save actual prescription ?</source>
        <translation>Sauvegarder la prescription actuelle ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="719"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
        <translation>La prescription actuelle n&apos;est pas vide. Voulez-vous la sauvegarder avant d&apos;en créer une nouvelle ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="821"/>
        <source>Opening a prescription : merge or replace ?</source>
        <translation>Ouverture d&apos;une prescription : fusionner ou remplacer ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="822"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
        <translation>Il existe déjà une prescription dans l&apos;éditeur, voulez-vous la remplacer ou ajouter la nouvelle prescription ?</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
        <source>Replace prescription</source>
        <translation>Remplacer la prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
        <source>Add to prescription</source>
        <translation>Ajouter à la prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="824"/>
        <source>Open a prescription</source>
        <translation>Ouvrerture d&apos;une prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="865"/>
        <source>Toggle patient&apos;s precautions</source>
        <translation>Afficher/cacher les précautions</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="213"/>
        <source>Preparing dosage transmission</source>
        <translation>Préparation de la transmission des posologies</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="91"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Configuration automatique pour l&apos;utilisation avec MedinTux</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="92"/>
        <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
        <translation>Cet assistant va créer une nouvelle entrée dans le menu utilsateur de DrTux.
Vous pourrez créer de nouvelles prescriptions depuis ce menu.
Attention, assurez-vous de reconfigurer MedinTux grâce à cet assistant à chaque fois que MedinTux ou FreeDiams changera de répertoire.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="97"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Cet assistant va essayer de trouver votre configuration de MedinTux. S&apos;il ne trouve pas, vous devrez l&apos;en informer. Ensuite, cet assistant configurera un nouveau menu utilisateur et ajoutera une liste dans vos listes par défauts des prescriptions.
Merci de prendre connaissance de la documentation.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="112"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Veuillez sélectionner le répertoire contenant le binaire de Manager</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="123"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le répertoire des ressources n&apos;existe pas. Chemin vers DrTux : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="128"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le menu utilisateur n&apos;existe pas et ne peut pas être créer. Chemin vers DrTux : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="140"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Impossible d&apos;effacer l&apos;ancienne entrée de DrugsInteractions du menu %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="147"/>
        <source>Unable to configure MedinTux : DrugsInteractions menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Impossible de configurer MedinTux : le menu de FreeDiams n&apos;existe pas et ne peut pas être créé. Chemin vers Drux : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="224"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux est maintenant configuré pour %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="225"/>
        <source>You can run %1 using DrTux User&apos;s Menu.</source>
        <translation>Vous pouvez utiliser %1 grâce au menu utilisateur de DrTux.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="226"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Si vous rencontrez des difficultés avec l&apos;intégration à DrTux, veuillez vous référer à la documentation des deux applications.
%1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="228"/>
        <source>DrTux is not correctly configured.</source>
        <translation>DrTux n&apos;est pas correctement configuré.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="229"/>
        <source>This assitant encountered errors during its process.</source>
        <translation>Cet assistant a rencontré des erreurs pendant la configuration.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="230"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Voici les messages des processus 
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="50"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Prescrire avec FreeDiams</translation>
    </message>
</context>
</TS>
